locks

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 27, 2021 License: Apache-2.0 Imports: 5 Imported by: 0

README

What contains this folder ?

Here you have all information about the package in the installation thats generate a moldy.lock

Note:

If create a single command you need create what make this folder

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetContents

func GetContents(pkgname string) map[string]interface{}

func WriteLock

func WriteLock(name string)

func WriteLockUrl

func WriteLockUrl(url string)

Types

This section is empty.

Jump to